from setuptools import setup

setup(
    name='LogicCircuit',
    version='0.0.1',
    description='Simple circuit builder only using logic gates',
    long_description='',
    url='https://github.com/TINYT1ME/LogicCircuit',
    author='TINYT1ME',
)

